Class: Aws::DataExchange::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DataExchange::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-dataexchange/client.rb,
sig/client.rbs
Overview
An API client for DataExchange. To construct a client, you need to configure a :region and :credentials.
client = Aws::DataExchange::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptDataGrantResponseSuccess, _CreateDataGrantResponseSuccess, _CreateDataSetResponseSuccess, _CreateEventActionResponseSuccess, _CreateJobResponseSuccess, _CreateRevisionResponseSuccess, _GetAssetResponseSuccess, _GetDataGrantResponseSuccess, _GetDataSetResponseSuccess, _GetEventActionResponseSuccess, _GetJobResponseSuccess, _GetReceivedDataGrantResponseSuccess, _GetRevisionResponseSuccess, _ListDataGrantsResponseSuccess, _ListDataSetRevisionsResponseSuccess, _ListDataSetsResponseSuccess, _ListEventActionsResponseSuccess, _ListJobsResponseSuccess, _ListReceivedDataGrantsResponseSuccess, _ListRevisionAssetsResponseSuccess, _ListTagsForResourceResponseSuccess, _RevokeRevisionResponseSuccess, _SendApiAssetResponseSuccess, _SendDataSetNotificationResponseSuccess, _StartJobResponseSuccess, _UpdateAssetResponseSuccess, _UpdateDataSetResponseSuccess, _UpdateEventActionResponseSuccess, _UpdateRevisionResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_data_grant(params = {}) ⇒ Types::AcceptDataGrantResponse
This operation accepts a data grant.
-
#cancel_job(params = {}) ⇒ Struct
This operation cancels a job.
-
#create_data_grant(params = {}) ⇒ Types::CreateDataGrantResponse
This operation creates a data grant.
-
#create_data_set(params = {}) ⇒ Types::CreateDataSetResponse
This operation creates a data set.
-
#create_event_action(params = {}) ⇒ Types::CreateEventActionResponse
This operation creates an event action.
-
#create_job(params = {}) ⇒ Types::CreateJobResponse
This operation creates a job.
-
#create_revision(params = {}) ⇒ Types::CreateRevisionResponse
This operation creates a revision for a data set.
-
#delete_asset(params = {}) ⇒ Struct
This operation deletes an asset.
-
#delete_data_grant(params = {}) ⇒ Struct
This operation deletes a data grant.
-
#delete_data_set(params = {}) ⇒ Struct
This operation deletes a data set.
-
#delete_event_action(params = {}) ⇒ Struct
This operation deletes the event action.
-
#delete_revision(params = {}) ⇒ Struct
This operation deletes a revision.
-
#get_asset(params = {}) ⇒ Types::GetAssetResponse
This operation returns information about an asset.
-
#get_data_grant(params = {}) ⇒ Types::GetDataGrantResponse
This operation returns information about a data grant.
-
#get_data_set(params = {}) ⇒ Types::GetDataSetResponse
This operation returns information about a data set.
-
#get_event_action(params = {}) ⇒ Types::GetEventActionResponse
This operation retrieves information about an event action.
-
#get_job(params = {}) ⇒ Types::GetJobResponse
This operation returns information about a job.
-
#get_received_data_grant(params = {}) ⇒ Types::GetReceivedDataGrantResponse
This operation returns information about a received data grant.
-
#get_revision(params = {}) ⇒ Types::GetRevisionResponse
This operation returns information about a revision.
-
#list_data_grants(params = {}) ⇒ Types::ListDataGrantsResponse
This operation returns information about all data grants.
-
#list_data_set_revisions(params = {}) ⇒ Types::ListDataSetRevisionsResponse
This operation lists a data set's revisions sorted by CreatedAt in descending order.
-
#list_data_sets(params = {}) ⇒ Types::ListDataSetsResponse
This operation lists your data sets.
-
#list_event_actions(params = {}) ⇒ Types::ListEventActionsResponse
This operation lists your event actions.
-
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
This operation lists your jobs sorted by CreatedAt in descending order.
-
#list_received_data_grants(params = {}) ⇒ Types::ListReceivedDataGrantsResponse
This operation returns information about all received data grants.
-
#list_revision_assets(params = {}) ⇒ Types::ListRevisionAssetsResponse
This operation lists a revision's assets sorted alphabetically in descending order.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
This operation lists the tags on the resource.
-
#revoke_revision(params = {}) ⇒ Types::RevokeRevisionResponse
This operation revokes subscribers' access to a revision.
-
#send_api_asset(params = {}) ⇒ Types::SendApiAssetResponse
This operation invokes an API Gateway API asset.
-
#send_data_set_notification(params = {}) ⇒ Struct
The type of event associated with the data set.
-
#start_job(params = {}) ⇒ Struct
This operation starts a job.
-
#tag_resource(params = {}) ⇒ Struct
This operation tags a resource.
-
#untag_resource(params = {}) ⇒ Struct
This operation removes one or more tags from a resource.
-
#update_asset(params = {}) ⇒ Types::UpdateAssetResponse
This operation updates an asset.
-
#update_data_set(params = {}) ⇒ Types::UpdateDataSetResponse
This operation updates a data set.
-
#update_event_action(params = {}) ⇒ Types::UpdateEventActionResponse
This operation updates the event action.
-
#update_revision(params = {}) ⇒ Types::UpdateRevisionResponse
This operation updates a revision.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-dataexchange/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2800 2801 2802 |
# File 'lib/aws-sdk-dataexchange/client.rb', line 2800 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2803 2804 2805 |
# File 'lib/aws-sdk-dataexchange/client.rb', line 2803 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_data_grant(params = {}) ⇒ Types::AcceptDataGrantResponse
This operation accepts a data grant.
98 |
# File 'sig/client.rbs', line 98
def accept_data_grant: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2773 2774 2775 2776 2777 2778 2779 2780 2781 2782 2783 2784 2785 2786 2787 2788 2789 |
# File 'lib/aws-sdk-dataexchange/client.rb', line 2773 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DataExchange') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-dataexchange' context[:gem_version] = '1.87.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_job(params = {}) ⇒ Struct
This operation cancels a job. Jobs can be cancelled only when they are in the WAITING state.
104 |
# File 'sig/client.rbs', line 104
def cancel_job: (
|
#create_data_grant(params = {}) ⇒ Types::CreateDataGrantResponse
This operation creates a data grant.
128 |
# File 'sig/client.rbs', line 128
def create_data_grant: (
|
#create_data_set(params = {}) ⇒ Types::CreateDataSetResponse
This operation creates a data set.
154 |
# File 'sig/client.rbs', line 154
def create_data_set: (
|
#create_event_action(params = {}) ⇒ Types::CreateEventActionResponse
This operation creates an event action.
173 |
# File 'sig/client.rbs', line 173
def create_event_action: (
|
#create_job(params = {}) ⇒ Types::CreateJobResponse
This operation creates a job.
197 |
# File 'sig/client.rbs', line 197
def create_job: (
|
#create_revision(params = {}) ⇒ Types::CreateRevisionResponse
This operation creates a revision for a data set.
336 |
# File 'sig/client.rbs', line 336
def create_revision: (
|
#delete_asset(params = {}) ⇒ Struct
This operation deletes an asset.
344 |
# File 'sig/client.rbs', line 344
def delete_asset: (
|
#delete_data_grant(params = {}) ⇒ Struct
This operation deletes a data grant.
352 |
# File 'sig/client.rbs', line 352
def delete_data_grant: (
|
#delete_data_set(params = {}) ⇒ Struct
This operation deletes a data set.
358 |
# File 'sig/client.rbs', line 358
def delete_data_set: (
|
#delete_event_action(params = {}) ⇒ Struct
This operation deletes the event action.
364 |
# File 'sig/client.rbs', line 364
def delete_event_action: (
|
#delete_revision(params = {}) ⇒ Struct
This operation deletes a revision.
370 |
# File 'sig/client.rbs', line 370
def delete_revision: (
|
#get_asset(params = {}) ⇒ Types::GetAssetResponse
This operation returns information about an asset.
391 |
# File 'sig/client.rbs', line 391
def get_asset: (
|
#get_data_grant(params = {}) ⇒ Types::GetDataGrantResponse
This operation returns information about a data grant.
417 |
# File 'sig/client.rbs', line 417
def get_data_grant: (
|
#get_data_set(params = {}) ⇒ Types::GetDataSetResponse
This operation returns information about a data set.
437 |
# File 'sig/client.rbs', line 437
def get_data_set: (
|
#get_event_action(params = {}) ⇒ Types::GetEventActionResponse
This operation retrieves information about an event action.
453 |
# File 'sig/client.rbs', line 453
def get_event_action: (
|
#get_job(params = {}) ⇒ Types::GetJobResponse
This operation returns information about a job.
471 |
# File 'sig/client.rbs', line 471
def get_job: (
|
#get_received_data_grant(params = {}) ⇒ Types::GetReceivedDataGrantResponse
This operation returns information about a received data grant.
493 |
# File 'sig/client.rbs', line 493
def get_received_data_grant: (
|
#get_revision(params = {}) ⇒ Types::GetRevisionResponse
This operation returns information about a revision.
514 |
# File 'sig/client.rbs', line 514
def get_revision: (
|
#list_data_grants(params = {}) ⇒ Types::ListDataGrantsResponse
This operation returns information about all data grants.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
526 |
# File 'sig/client.rbs', line 526
def list_data_grants: (
|
#list_data_set_revisions(params = {}) ⇒ Types::ListDataSetRevisionsResponse
This operation lists a data set's revisions sorted by CreatedAt in descending order.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
538 |
# File 'sig/client.rbs', line 538
def list_data_set_revisions: (
|
#list_data_sets(params = {}) ⇒ Types::ListDataSetsResponse
This operation lists your data sets. When listing by origin OWNED, results are sorted by CreatedAt in descending order. When listing by origin ENTITLED, there is no order.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
551 |
# File 'sig/client.rbs', line 551
def list_data_sets: (
|
#list_event_actions(params = {}) ⇒ Types::ListEventActionsResponse
This operation lists your event actions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
564 |
# File 'sig/client.rbs', line 564
def list_event_actions: (
|
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
This operation lists your jobs sorted by CreatedAt in descending order.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
577 |
# File 'sig/client.rbs', line 577
def list_jobs: (
|
#list_received_data_grants(params = {}) ⇒ Types::ListReceivedDataGrantsResponse
This operation returns information about all received data grants.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
591 |
# File 'sig/client.rbs', line 591
def list_received_data_grants: (
|
#list_revision_assets(params = {}) ⇒ Types::ListRevisionAssetsResponse
This operation lists a revision's assets sorted alphabetically in descending order.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
604 |
# File 'sig/client.rbs', line 604
def list_revision_assets: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
This operation lists the tags on the resource.
617 |
# File 'sig/client.rbs', line 617
def list_tags_for_resource: (
|
#revoke_revision(params = {}) ⇒ Types::RevokeRevisionResponse
This operation revokes subscribers' access to a revision.
637 |
# File 'sig/client.rbs', line 637
def revoke_revision: (
|
#send_api_asset(params = {}) ⇒ Types::SendApiAssetResponse
This operation invokes an API Gateway API asset. The request is proxied to the provider’s API Gateway API.
650 |
# File 'sig/client.rbs', line 650
def send_api_asset: (
|
#send_data_set_notification(params = {}) ⇒ Struct
The type of event associated with the data set.
666 |
# File 'sig/client.rbs', line 666
def send_data_set_notification: (
|
#start_job(params = {}) ⇒ Struct
This operation starts a job.
720 |
# File 'sig/client.rbs', line 720
def start_job: (
|
#tag_resource(params = {}) ⇒ Struct
This operation tags a resource.
726 |
# File 'sig/client.rbs', line 726
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
This operation removes one or more tags from a resource.
733 |
# File 'sig/client.rbs', line 733
def untag_resource: (
|
#update_asset(params = {}) ⇒ Types::UpdateAssetResponse
This operation updates an asset.
753 |
# File 'sig/client.rbs', line 753
def update_asset: (
|
#update_data_set(params = {}) ⇒ Types::UpdateDataSetResponse
This operation updates a data set.
775 |
# File 'sig/client.rbs', line 775
def update_data_set: (
|
#update_event_action(params = {}) ⇒ Types::UpdateEventActionResponse
This operation updates the event action.
792 |
# File 'sig/client.rbs', line 792
def update_event_action: (
|
#update_revision(params = {}) ⇒ Types::UpdateRevisionResponse
This operation updates a revision.
813 |
# File 'sig/client.rbs', line 813
def update_revision: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2793 2794 2795 |
# File 'lib/aws-sdk-dataexchange/client.rb', line 2793 def waiter_names [] end |