Class: Aws::DataExchange::Types::ImportAssetFromApiGatewayApiResponseDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataExchange::Types::ImportAssetFromApiGatewayApiResponseDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dataexchange/types.rb
Overview
The response details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#api_description ⇒ String
The API description.
-
#api_id ⇒ String
The API ID.
-
#api_key ⇒ String
The API key.
-
#api_name ⇒ String
The API name.
-
#api_specification_md_5_hash ⇒ String
The Base64-encoded Md5 hash for the API asset, used to ensure the integrity of the API at that location.
-
#api_specification_upload_url ⇒ String
The upload URL of the API specification.
-
#api_specification_upload_url_expires_at ⇒ Time
The date and time that the upload URL expires, in ISO 8601 format.
-
#data_set_id ⇒ String
The data set ID.
-
#protocol_type ⇒ String
The protocol type.
-
#revision_id ⇒ String
The revision ID.
-
#stage ⇒ String
The API stage.
Instance Attribute Details
#api_description ⇒ String
The API description.
2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 |
# File 'lib/aws-sdk-dataexchange/types.rb', line 2179 class ImportAssetFromApiGatewayApiResponseDetails < Struct.new( :api_description, :api_id, :api_key, :api_name, :api_specification_md_5_hash, :api_specification_upload_url, :api_specification_upload_url_expires_at, :data_set_id, :protocol_type, :revision_id, :stage) SENSITIVE = [] include Aws::Structure end |
#api_id ⇒ String
The API ID.
2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 |
# File 'lib/aws-sdk-dataexchange/types.rb', line 2179 class ImportAssetFromApiGatewayApiResponseDetails < Struct.new( :api_description, :api_id, :api_key, :api_name, :api_specification_md_5_hash, :api_specification_upload_url, :api_specification_upload_url_expires_at, :data_set_id, :protocol_type, :revision_id, :stage) SENSITIVE = [] include Aws::Structure end |
#api_key ⇒ String
The API key.
2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 |
# File 'lib/aws-sdk-dataexchange/types.rb', line 2179 class ImportAssetFromApiGatewayApiResponseDetails < Struct.new( :api_description, :api_id, :api_key, :api_name, :api_specification_md_5_hash, :api_specification_upload_url, :api_specification_upload_url_expires_at, :data_set_id, :protocol_type, :revision_id, :stage) SENSITIVE = [] include Aws::Structure end |
#api_name ⇒ String
The API name.
2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 |
# File 'lib/aws-sdk-dataexchange/types.rb', line 2179 class ImportAssetFromApiGatewayApiResponseDetails < Struct.new( :api_description, :api_id, :api_key, :api_name, :api_specification_md_5_hash, :api_specification_upload_url, :api_specification_upload_url_expires_at, :data_set_id, :protocol_type, :revision_id, :stage) SENSITIVE = [] include Aws::Structure end |
#api_specification_md_5_hash ⇒ String
The Base64-encoded Md5 hash for the API asset, used to ensure the integrity of the API at that location.
2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 |
# File 'lib/aws-sdk-dataexchange/types.rb', line 2179 class ImportAssetFromApiGatewayApiResponseDetails < Struct.new( :api_description, :api_id, :api_key, :api_name, :api_specification_md_5_hash, :api_specification_upload_url, :api_specification_upload_url_expires_at, :data_set_id, :protocol_type, :revision_id, :stage) SENSITIVE = [] include Aws::Structure end |
#api_specification_upload_url ⇒ String
The upload URL of the API specification.
2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 |
# File 'lib/aws-sdk-dataexchange/types.rb', line 2179 class ImportAssetFromApiGatewayApiResponseDetails < Struct.new( :api_description, :api_id, :api_key, :api_name, :api_specification_md_5_hash, :api_specification_upload_url, :api_specification_upload_url_expires_at, :data_set_id, :protocol_type, :revision_id, :stage) SENSITIVE = [] include Aws::Structure end |
#api_specification_upload_url_expires_at ⇒ Time
The date and time that the upload URL expires, in ISO 8601 format.
2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 |
# File 'lib/aws-sdk-dataexchange/types.rb', line 2179 class ImportAssetFromApiGatewayApiResponseDetails < Struct.new( :api_description, :api_id, :api_key, :api_name, :api_specification_md_5_hash, :api_specification_upload_url, :api_specification_upload_url_expires_at, :data_set_id, :protocol_type, :revision_id, :stage) SENSITIVE = [] include Aws::Structure end |
#data_set_id ⇒ String
The data set ID.
2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 |
# File 'lib/aws-sdk-dataexchange/types.rb', line 2179 class ImportAssetFromApiGatewayApiResponseDetails < Struct.new( :api_description, :api_id, :api_key, :api_name, :api_specification_md_5_hash, :api_specification_upload_url, :api_specification_upload_url_expires_at, :data_set_id, :protocol_type, :revision_id, :stage) SENSITIVE = [] include Aws::Structure end |
#protocol_type ⇒ String
The protocol type.
2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 |
# File 'lib/aws-sdk-dataexchange/types.rb', line 2179 class ImportAssetFromApiGatewayApiResponseDetails < Struct.new( :api_description, :api_id, :api_key, :api_name, :api_specification_md_5_hash, :api_specification_upload_url, :api_specification_upload_url_expires_at, :data_set_id, :protocol_type, :revision_id, :stage) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
The revision ID.
2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 |
# File 'lib/aws-sdk-dataexchange/types.rb', line 2179 class ImportAssetFromApiGatewayApiResponseDetails < Struct.new( :api_description, :api_id, :api_key, :api_name, :api_specification_md_5_hash, :api_specification_upload_url, :api_specification_upload_url_expires_at, :data_set_id, :protocol_type, :revision_id, :stage) SENSITIVE = [] include Aws::Structure end |
#stage ⇒ String
The API stage.
2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 |
# File 'lib/aws-sdk-dataexchange/types.rb', line 2179 class ImportAssetFromApiGatewayApiResponseDetails < Struct.new( :api_description, :api_id, :api_key, :api_name, :api_specification_md_5_hash, :api_specification_upload_url, :api_specification_upload_url_expires_at, :data_set_id, :protocol_type, :revision_id, :stage) SENSITIVE = [] include Aws::Structure end |